#############
Create a page
#############

.. _create-first-page:

**********************
Create your first page
**********************

django CMS's *Create Page wizard* will open a new dialog box.

.. image:: /user/tutorial/images/welcome.png
   :alt: The 'Create Page wizard'
   :width: 400
   :align: center

Select *Next*, and provide a *Title* and some basic text content for the new page (you'll be
able to add formatting to this text in a moment), then hit **Create**.

.. image:: /user/tutorial/images/add-title-and-content.png
   :alt: Add Title and Content
   :width: 400
   :align: center

.. |publish-page-now| image:: /user/tutorial/images/publish-page-now.png
   :alt: 'Publish page now'

Here's your newly-created page, together with the *django CMS toolbar*, your primary tool for
managing django CMS content.


**************
Publish a page
**************

Your newly-created page is just a *draft*, and won't actually be published until you decide. As an
editor, you can see drafts, but other visitors to your site will only see published pages. Hit
|publish-page-now| to publish it.

.. image:: /user/tutorial/images/newly-created.png
   :alt: Newly-created page

.. |edit| image:: /user/tutorial/images/edit-button.png
   :alt: 'Edit'

.. |view-published| image:: /user/tutorial/images/view-published.png
   :alt: 'View published'

To edit the page further, switch back into editing mode, using the |edit| button that appears, and
return to the *published* version of the page using the |view-published| button.

In editing mode, double-click on the paragraph of text to change it. This will open the Text plugin
containing it. Make changes, add some formatting, and **Save** it again.

You can continue making and previewing changes privately until you are ready to publish them.


********************
Create a second page
********************

.. |create| image:: /user/tutorial/images/create.png
   :alt: 'Create'

Hit |create| to create a second page. This opens the *Create page* dialog:

.. image:: /user/tutorial/images/create-page-dialog.png
   :alt: the 'Create page' dialog

In django CMS, pages can be arranged hierarchically. This is important for larger sites. Choose
whether the new page should be a sub-page - a child - of the existing page, or be on the same level
in the hierarchy - a sibling.

Once again, give the page a *Title* and some basic text content. Continue making changes to content
and formatting, and then **Publish** it as you did previously.
